@@ -1,5 +1,5 @@
 from invisibleroads.scripts import ConfigurableScript
-from invisibleroads_macros.disk import make_folder, remove_path
+from invisibleroads_macros_disk import make_folder, remove_folder
 from pyramid.paster import get_appsettings
 
 
@@ -8,13 +8,13 @@ class InitializePostsScript(ConfigurableScript):
     priority = 10
 
     def configure(self, argument_subparser):
-        super(ConfigurableScript, self).configure(argument_subparser)
+        super(InitializePostsScript, self).configure(argument_subparser)
         argument_subparser.add_argument('--restart', action='store_true')
 
     def run(self, args):
         settings = get_appsettings(args.configuration_path)
         if args.restart and 'data.folder' in settings:
-            remove_path(settings['data.folder'])
+            remove_folder(settings['data.folder'])
         for key, value in settings.items():
             if key.endswith('.folder'):
                 make_folder(value)
